@@ -1,5 +1,5 @@
 import logging
-
+import pandas as pd
 from object import PyObject, PyObjects
 
 logger = logging.getLogger("PyTabular")
@@ -15,12 +15,18 @@ class PyMeasure(PyObject):
 
     def __init__(self, object, table) -> None:
         super().__init__(object)
+
         self.Table = table
         self._display.add_row("Expression", self._object.Expression, end_section=True)
         self._display.add_row("DisplayFolder", self._object.DisplayFolder)
         self._display.add_row("IsHidden", str(self._object.IsHidden))
         self._display.add_row("FormatString", self._object.FormatString)
 
+    def get_dependencies(self) -> pd.DataFrame:
+        """Returns the dependant columns of a measure"""
+        dmv_query = f"select * from $SYSTEM.DISCOVER_CALC_DEPENDENCY where [OBJECT] = '{self.Name}' and [TABLE] = '{self.Table.Name}'"
+        return self.Table.Model.Query(dmv_query)
+
 
 class PyMeasures(PyObjects):
     def __init__(self, objects) -> None:
